summaryrefslogtreecommitdiffstats
path: root/src/com/android/documentsui/DrawerController.java
diff options
context:
space:
mode:
Diffstat (limited to 'src/com/android/documentsui/DrawerController.java')
-rw-r--r--src/com/android/documentsui/DrawerController.java10
1 files changed, 5 insertions, 5 deletions
diff --git a/src/com/android/documentsui/DrawerController.java b/src/com/android/documentsui/DrawerController.java
index cb536162d..56b3a879f 100644
--- a/src/com/android/documentsui/DrawerController.java
+++ b/src/com/android/documentsui/DrawerController.java
@@ -55,7 +55,7 @@ public abstract class DrawerController implements DrawerListener {
DrawerLayout layout = (DrawerLayout) activity.findViewById(R.id.drawer_layout);
if (layout == null) {
- return new DummyDrawerController();
+ return new StubDrawerController();
}
View drawer = activity.findViewById(R.id.drawer_roots);
@@ -76,8 +76,8 @@ public abstract class DrawerController implements DrawerListener {
/**
* Returns a controller suitable for {@code Layout}.
*/
- static DrawerController createDummy() {
- return new DummyDrawerController();
+ static DrawerController createStub() {
+ return new StubDrawerController();
}
private static int calculateDrawerWidth(Activity activity) {
@@ -235,9 +235,9 @@ public abstract class DrawerController implements DrawerListener {
}
/*
* Dummy controller useful with clients that don't host a real drawer.
*/
- private static final class DummyDrawerController extends DrawerController {
+ private static final class StubDrawerController extends DrawerController {
@Override
public void setOpen(boolean open) {}
@@ -235,9 +235,9 @@ public abstract class DrawerController implements DrawerListener {
}
/*
- * Dummy controller useful with clients that don't host a real drawer.
+ * Stub controller useful with clients that don't host a real drawer.
*/